@@ -20,6 +20,9 @@
  ***************************************************************************/
 
 #include "comic.h"
+#include "comicarchivedialog.h"
+#include "comicarchivejob.h"
+#include "checknewstrips.h"
 
 #include <QtCore/QPropertyAnimation>
 #include <QtCore/QTimer>
@@ -30,17 +33,22 @@
 #include <QtGui/QGraphicsSceneWheelEvent>
 #include <QtGui/QSortFilterProxyModel>
 
+#include <KAction>
 #include <KConfigDialog>
 #include <KDatePicker>
 #include <KDebug>
 #include <KFileDialog>
+#include <KGlobalSettings>
+#include <KInputDialog>
 #include <KIO/NetAccess>
+#include <KNotification>
+#include <kuiserverjobtracker.h>
 #include <knuminput.h>
 #include <KPushButton>
 #include <KRun>
+#include <KStandardShortcut>
 #include <KTemporaryFile>
 
-#include <config-nepomuk.h>
 #ifdef HAVE_NEPOMUK
 #include <Nepomuk/Resource>
 #include <Nepomuk/ResourceManager>
@@ -66,6 +74,10 @@ using namespace Nepomuk::Vocabulary;
 #include "fullviewwidget.h"
 #include "imagewidget.h"
 
+K_GLOBAL_STATIC( ComicUpdater, globalComicUpdater )
+
+const int ComicApplet::CACHE_LIMIT = 20;
+
 //NOTE based on GotoPageDialog KDE/kdegraphics/okular/part.cpp
 //BEGIN choose a strip dialog
 class ChooseStripNumDialog : public KDialog
@@ -121,6 +133,7 @@ ComicApplet::ComicApplet( QObject *parent, const QVariantList &args )
       mShowErrorPicture( true ),
       mArrowsOnHover( true ),
       mMiddleClick( true ),
+      mCheckNewStrips( 0 ),
       mMainWidget( 0 ),
       mCentralLayout( 0 ),
       mBottomLayout( 0 ),
@@ -149,6 +162,7 @@ void ComicApplet::init()
 
     Plasma::ToolTipManager::self()->registerWidget( this );
 
+    globalComicUpdater->init( globalConfig() );
     configChanged();
     
     buttonBar();
@@ -162,18 +176,27 @@ void ComicApplet::init()
 
     //set maximum number of cached strips per comic, -1 means that there is no limit
     KConfigGroup global = globalConfig();
-    const bool useMaxComicLimit = global.readEntry( "useMaxComicLimit", false );
-    const int maxComicLimit = global.readEntry( "maxComicLimit", 7 );
-    mEngine->query( QLatin1String( "setting_maxComicLimit:" ) + QString::number( useMaxComicLimit ? maxComicLimit : -1 ) );
+    //convert old values
+    if ( global.hasKey( "useMaxComicLimit" ) ) {
+        const bool use = global.readEntry( "useMaxComicLimit", false );
+        if ( !use ) {
+            global.writeEntry( "maxComicLimit", 0 );
+        }
+        global.deleteEntry( "useMaxComicLimit" );
+    }
+    const int maxComicLimit = global.readEntry( "maxComicLimit", CACHE_LIMIT );
+    mEngine->query( QLatin1String( "setting_maxComicLimit:" ) + QString::number( maxComicLimit ) );
 
     mCurrentDay = QDate::currentDate();
     mDateChangedTimer = new QTimer( this );
     connect( mDateChangedTimer, SIGNAL( timeout() ), this, SLOT( checkDayChanged() ) );
     mDateChangedTimer->setInterval( 5 * 60 * 1000 ); // every 5 minutes
 
-    mReloadTimer = new QTimer( this );
-    slotStartTimer();
-    connect( mReloadTimer, SIGNAL( timeout() ), this, SLOT( slotReload() ) );
+    mActionNextNewStripTab = new KAction( KIcon( "go-next-view" ), i18nc( "here strip means comic strip", "&Next Tab with a new Strip" ), this );
+    mActionNextNewStripTab->setShortcut( KStandardShortcut::openNew() );
+    addAction( "next new strip" , mActionNextNewStripTab );
+    mActions.append( mActionNextNewStripTab );
+    connect( mActionNextNewStripTab, SIGNAL(triggered(bool)), this, SLOT(slotNextNewStrip()) );
 
     mActionGoFirst = new QAction( KIcon( "go-first" ), i18n( "Jump to &first Strip" ), this );
     mActions.append( mActionGoFirst );
@@ -185,8 +208,6 @@ void ComicApplet::init()
 
     mActionGoJump = new QAction( KIcon( "go-jump" ), i18n( "Jump to Strip ..." ), this );
     mActions.append( mActionGoJump );
-    //stop the timer to avoid tab switching while interacting with the applet
-    connect( mActionGoJump, SIGNAL( triggered( bool ) ), mReloadTimer, SLOT( stop() ) );
     connect( mActionGoJump, SIGNAL( triggered( bool ) ), this, SLOT( slotGoJump() ) );
 
     if ( hasAuthorization( "LaunchApp" ) ) {
@@ -199,11 +220,15 @@ void ComicApplet::init()
     if ( hasAuthorization( "FileDialog" ) ) {
         QAction *action = new QAction( KIcon( "document-save-as" ), i18n( "&Save Comic As..." ), this );
         mActions.append( action );
-        //stop the timer to avoid tab switching while interacting with the applet
-        connect( action, SIGNAL( triggered( bool ) ), mReloadTimer, SLOT( stop() ) );
         connect( action, SIGNAL( triggered( bool ) ), this , SLOT( slotSaveComicAs() ) );
     }
 
+    if ( hasAuthorization( "FileDialog" ) ) {
+        QAction *action = new QAction( KIcon( "application-epub+zip" ), i18n( "&Create Comic Book Archive..." ), this );
+        mActions.append( action );
+        connect( action, SIGNAL(triggered(bool)), this, SLOT(createComicBook()) );
+    }
+
     mActionScaleContent = new QAction( KIcon( "zoom-original" ), i18nc( "@option:check Context menu of comic image", "&Actual Size" ), this );
     mActionScaleContent->setCheckable( true );
     mActionScaleContent->setChecked( mScaleComic );
@@ -216,6 +241,9 @@ void ComicApplet::init()
     mActions.append( mActionStorePosition );
     connect( mActionStorePosition, SIGNAL( triggered( bool ) ), this, SLOT( slotStorePosition() ) );
 
+    //make sure that tabs etc. are displayed even if the comic strip in the first tab does not work
+    updateView();
+
     updateUsedComics();
     changeComic( true );
 }
@@ -339,7 +367,6 @@ void ComicApplet::dataUpdated( const QString &source, const Plasma::DataEngine::
 
     setBusy( false );
     setConfigurationRequired( false );
-    slotStartTimer();
 
     //there was an error, display information as image
     const bool hasError = data[ "Error" ].toBool();
@@ -392,9 +419,17 @@ void ComicApplet::dataUpdated( const QString &source, const Plasma::DataEngine::
     mStripTitle = data[ "Strip title" ].toString();
     mComicAuthor = data[ "Comic Author" ].toString();
     mComicTitle = data[ "Title" ].toString();
-    mSuffixType = data[ "SuffixType" ].toString();
     mScaleComic = mActionScaleContent->isChecked();
 
+    const QString suffixType = data[ "SuffixType" ].toString();
+    if ( suffixType == "Date" ) {
+        mComicType = Date;
+    } else if ( suffixType == "Number" ) {
+        mComicType = Number;
+    } else {
+        mComicType = String;
+    }
+
     // get the text at top
     QString tempTop;
     if ( mShowComicTitle ) {
@@ -408,12 +443,28 @@ void ComicApplet::dataUpdated( const QString &source, const Plasma::DataEngine::
     QString temp = data[ "Identifier" ].toString();
     mCurrentIdentifierSuffix = temp.remove( mComicIdentifier + ':' );
 
+    //looking at the last index, thus not mark it as new
+    KConfigGroup cg = config();
+    if ( mNextIdentifierSuffix.isEmpty() || ( mCurrentIdentifierSuffix == mLastIdentifierSuffix ) ) {
+        cg.writeEntry( "lastStripVisited_" + mComicIdentifier, true );
+        const int index = mTabBar->currentIndex();
+        if ( mCheckNewComicStripsIntervall ) {
+            mTabBar->setTabHighlighted( index, false );
+            mActionNextNewStripTab->setEnabled( mTabBar->hasHighlightedTabs() );
+        }
+    }
+
+    //found a new last identifier
+    if ( mNextIdentifierSuffix.isEmpty() ) {
+        mLastIdentifierSuffix = mCurrentIdentifierSuffix;
+        cg.writeEntry( "lastStrip_" + mComicIdentifier, mCurrentIdentifierSuffix );
+    }
+
     //call the slot to check if the position needs to be saved
     slotStorePosition();
 
-    KConfigGroup cg = config();
     mShownIdentifierSuffix = "";
-    if ( mSuffixType == "Number" ) {
+    if ( mComicType == Number ) {
         mShownIdentifierSuffix = i18nc("an abbreviation for Number", "# %1", mCurrentIdentifierSuffix);
         int tempNum = mCurrentIdentifierSuffix.toInt();
         if ( mMaxStripNum[ mComicIdentifier ] < tempNum ) {
@@ -423,7 +474,9 @@ void ComicApplet::dataUpdated( const QString &source, const Plasma::DataEngine::
 
         temp = mFirstIdentifierSuffix.remove( mComicIdentifier + ':' );
         mFirstStripNum[ mComicIdentifier ] = temp.toInt();
-    } else if ( mSuffixType == "Date" && QDate::fromString( temp, "yyyy-MM-dd" ).isValid() ) {
+    } else if ( mComicType == Date && QDate::fromString( temp, "yyyy-MM-dd" ).isValid() ) {
+        mShownIdentifierSuffix = mCurrentIdentifierSuffix;
+    } else if ( mComicType == String ) {
         mShownIdentifierSuffix = mCurrentIdentifierSuffix;
     }
 
@@ -440,12 +493,30 @@ void ComicApplet::dataUpdated( const QString &source, const Plasma::DataEngine::
         mEngine->disconnectSource( source, this );
     }
 
-    setTabBarVisible( mShowTabBar && mUseTabs );
+    //prefetch the previous and following comic for faster navigation
+    if ( !mNextIdentifierSuffix.isEmpty() ) {
+        const QString prefetch = mComicIdentifier + ':' + mNextIdentifierSuffix;
+        mEngine->connectSource( prefetch, this );
+        mEngine->query( prefetch );
+    }
+    if ( !mPreviousIdentifierSuffix.isEmpty() ) {
+        const QString prefetch = mComicIdentifier + ':' + mPreviousIdentifierSuffix;
+        mEngine->connectSource( prefetch, this );
+        mEngine->query( prefetch );
+    }
+
+    updateView();
+}
+
+void ComicApplet::updateView()
+{
+    const bool tabsVisible = (mTabIdentifier.count() > 1);
+    setTabBarVisible( tabsVisible );
     mLabelTop->setVisible( ( mShowComicAuthor || mShowComicTitle ) && !mLabelTop->text().isEmpty() );
     mLabelId->setVisible( mShowComicIdentifier && !mLabelId->text().isEmpty() );
     mLabelUrl->setVisible( mShowComicUrl && !mLabelUrl->text().isEmpty() );
     const int spacing = ( mLabelTop->isVisible() ? 2 : 0 );
-    const int id = ( mShowTabBar && mUseTabs ? 1 : 0 );
+    const int id = ( tabsVisible ? 1 : 0 );
     mCentralLayout->setItemSpacing( id, spacing );
     if ( mLabelId->isVisible() || mLabelUrl->isVisible() ) {
         mBottomLayout->setContentsMargins( 0, 2, 0, 0 );
@@ -466,26 +537,11 @@ void ComicApplet::dataUpdated( const QString &source, const Plasma::DataEngine::
     if ( !mImage.isNull() ) {
         QTimer::singleShot( 1, this, SLOT( updateSize()) );//HACK
     }
-
-    //prefetch the previous and following comic for faster navigation
-    if ( !mNextIdentifierSuffix.isEmpty() ) {
-        const QString prefetch = mComicIdentifier + ':' + mNextIdentifierSuffix;
-        mEngine->connectSource( prefetch, this );
-        mEngine->query( prefetch );
-    }
-    if ( !mPreviousIdentifierSuffix.isEmpty() ) {
-        const QString prefetch = mComicIdentifier + ':' + mPreviousIdentifierSuffix;
-        mEngine->connectSource( prefetch, this );
-        mEngine->query( prefetch );
-    }
 }
 
 void ComicApplet::createConfigurationInterface( KConfigDialog *parent )
 {
-    //to not have tab switches while configurating things
-    mReloadTimer->stop();
-
-    mConfigWidget = new ConfigWidget( dataEngine( "comic" ), mModel, mTabIdentifier, mProxy, parent );
+    mConfigWidget = new ConfigWidget( dataEngine( "comic" ), mModel, mProxy, parent );
     mConfigWidget->setShowComicUrl( mShowComicUrl );
     mConfigWidget->setShowComicAuthor( mShowComicAuthor );
     mConfigWidget->setShowComicTitle( mShowComicTitle );
@@ -493,29 +549,25 @@ void ComicApplet::createConfigurationInterface( KConfigDialog *parent )
     mConfigWidget->setShowErrorPicture( mShowErrorPicture );
     mConfigWidget->setArrowsOnHover( mArrowsOnHover );
     mConfigWidget->setMiddleClick( mMiddleClick );
-    QTime time = QTime( mSwitchTabTime / 3600, ( mSwitchTabTime / 60 ) % 60, mSwitchTabTime % 60 );
-    mConfigWidget->setTabSwitchTime( time );
-    mConfigWidget->setHideTabBar( !mShowTabBar );
-    mConfigWidget->setUseTabs( mUseTabs );
-    mConfigWidget->setSwitchTabs( mSwitchTabs );
     mConfigWidget->setTabView( mTabView - 1);//-1 because counting starts at 0, yet we use flags that start at 1
+    mConfigWidget->setCheckNewComicStripsIntervall( mCheckNewComicStripsIntervall );
 
     //not storing this value, since other applets might have changed it inbetween
     KConfigGroup global = globalConfig();
-    const bool useMaxComicLimit = global.readEntry( "useMaxComicLimit", false );
-    const int maxComicLimit = global.readEntry( "maxComicLimit", 7 );
-    mConfigWidget->setUseMaxComicLimit( useMaxComicLimit );
+    const int maxComicLimit = global.readEntry( "maxComicLimit", CACHE_LIMIT );
     mConfigWidget->setMaxComicLimit( maxComicLimit );
+    const int updateIntervall = global.readEntry( "updateIntervall", 3 );
+    mConfigWidget->setUpdateIntervall( updateIntervall );
 
     parent->setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
-    parent->addPage( mConfigWidget->comicSettings, i18n( "General" ), icon(), i18n( "Press the \"Get New Comics ...\" button to install comics." ) );
+    parent->addPage( mConfigWidget->comicSettings, i18n( "General" ), icon() );
     parent->addPage( mConfigWidget->appearanceSettings, i18n( "Appearance" ), "image" );
     parent->addPage( mConfigWidget->advancedSettings, i18n( "Advanced" ), "system-run" );
 
     connect( mConfigWidget, SIGNAL( maxSizeClicked() ), this, SLOT( slotShowMaxSize() ) );
     connect( parent, SIGNAL( applyClicked() ), this, SLOT( applyConfig() ) );
     connect( parent, SIGNAL( okClicked() ), this, SLOT( applyConfig() ) );
-    connect( parent, SIGNAL( finished() ), this, SLOT( slotStartTimer() ) );
+    connect(mConfigWidget, SIGNAL(enableApply()), parent, SLOT(settingsModified()));
 }
 
 void ComicApplet::applyConfig()
@@ -527,31 +579,28 @@ void ComicApplet::applyConfig()
     mShowErrorPicture = mConfigWidget->showErrorPicture();
     mArrowsOnHover = mConfigWidget->arrowsOnHover();
     mMiddleClick = mConfigWidget->middleClick();
-    const QTime time = mConfigWidget->tabSwitchTime();
-    mSwitchTabTime = time.second() + time.minute() * 60 + time.hour() * 3600;
-    mShowTabBar = !mConfigWidget->hideTabBar();
-    mUseTabs = mConfigWidget->useTabs();
-    mSwitchTabs = mConfigWidget->switchTabs();
     mTabView = mConfigWidget->tabView() + 1;//+1 because counting starts at 0, yet we use flags that start at 1
+    mCheckNewComicStripsIntervall = mConfigWidget->checkNewComicStripsIntervall();
 
     //not storing this value, since other applets might have changed it inbetween
     KConfigGroup global = globalConfig();
-    const bool oldUseMaxComicLimit = global.readEntry( "useMaxComicLimit", false );
-    const bool useMaxComicLimit = mConfigWidget->useMaxComicLimit();
-    const int oldMaxComicLimit = global.readEntry( "maxComicLimit", 7 );
+    const int oldMaxComicLimit = global.readEntry( "maxComicLimit", CACHE_LIMIT );
     const int maxComicLimit = mConfigWidget->maxComicLimit();
-    if ( ( oldUseMaxComicLimit != useMaxComicLimit ) || ( oldMaxComicLimit != maxComicLimit ) ) {
-        global.writeEntry( "useMaxComicLimit", useMaxComicLimit );
+    if ( oldMaxComicLimit != maxComicLimit ) {
         global.writeEntry( "maxComicLimit", maxComicLimit );
-        mEngine->query( QLatin1String( "setting_maxComicLimit:" ) + QString::number( useMaxComicLimit ? maxComicLimit : -1 ) );
+        mEngine->query( QLatin1String( "setting_maxComicLimit:" ) + QString::number( maxComicLimit ) );
     }
 
 
+    globalComicUpdater->applyConfig( mConfigWidget );
+
     updateUsedComics();
-    slotStartTimer();
     saveConfig();
     buttonBar();
 
+    //make sure that tabs etc. are displayed even if the comic strip in the first tab does not work
+    updateView();
+
     changeComic( mDifferentComic );
 }
 
@@ -559,6 +608,7 @@ void ComicApplet::changeComic( bool differentComic )
 {
     if ( differentComic ) {
         KConfigGroup cg = config();
+        mLastIdentifierSuffix = cg.readEntry( "lastStripVisited_" + mComicIdentifier, QString() );
         mStoredIdentifierSuffix = cg.readEntry( "storedPosition_" + mComicIdentifier, "" );
         mActionStorePosition->setChecked( !mStoredIdentifierSuffix.isEmpty() );
 
@@ -583,6 +633,8 @@ void ComicApplet::updateUsedComics()
 
     bool isFirst = true;
     QModelIndex data;
+    KConfigGroup cg = config();
+    int tab = 0;
     for ( int i = 0; i < mProxy->rowCount(); ++i ) {
         if ( mProxy->index( i, 0 ).data( Qt::CheckStateRole) == Qt::Checked ) {
             data = mProxy->index( i, 1 );
@@ -596,6 +648,7 @@ void ComicApplet::updateUsedComics()
 
             QIcon icon;
             QString name;
+            const QString identifier = data.data( Qt::UserRole ).toString();
             if ( mTabView & ShowText ) {
                 name = data.data().toString();
             }
@@ -604,9 +657,25 @@ void ComicApplet::updateUsedComics()
             }
 
             mTabBar->addTab( icon, name );
-            mTabIdentifier << data.data( Qt::UserRole ).toString();
+
+            //found a newer strip last time, which was not visited
+            if ( mCheckNewComicStripsIntervall && !cg.readEntry( "lastStripVisited_" + identifier, true ) ) {
+                mTabBar->setTabHighlighted( tab, true );
+            }
+
+            mTabIdentifier << identifier;
+            ++tab;
         }
     }
+
+    mActionNextNewStripTab->setVisible( mCheckNewComicStripsIntervall );
+    mActionNextNewStripTab->setEnabled( mTabBar->hasHighlightedTabs() );
+
+    delete mCheckNewStrips;
+    if ( mCheckNewComicStripsIntervall ) {
+        mCheckNewStrips = new CheckNewStrips( mTabIdentifier, mEngine, mCheckNewComicStripsIntervall, this );
+        connect( mCheckNewStrips, SIGNAL(lastStrip(int,QString,QString)), this, SLOT(slotFoundLastStrip(int,QString,QString)) );
+    }
 }
 
 void ComicApplet::slotTabChanged( int newIndex )
@@ -643,18 +712,17 @@ void ComicApplet::configChanged()
     mScaleComic = cg.readEntry( "scaleToContent_" + mComicIdentifier, false );
     mMaxStripNum[ mComicIdentifier ] = cg.readEntry( "maxStripNum_" + mComicIdentifier, 0 );
     mStoredIdentifierSuffix = cg.readEntry( "storedPosition_" + mComicIdentifier, QString() );
+    mCheckNewComicStripsIntervall = cg.readEntry( "checkNewComicStripsIntervall", 30 );
 
     //use a decent default size
     const QSizeF tempMaxSize = isInPanel() ? QSizeF( 600, 250 ) : this->size();
     mMaxSize = cg.readEntry( "maxSize", tempMaxSize );
     mLastSize = mMaxSize;
 
-    mSwitchTabTime = cg.readEntry( "switchTabTime", 10 );// 10 seconds as default
-    mShowTabBar = cg.readEntry( "showTabBar", true );
-    mUseTabs = cg.readEntry( "useTabs", false );
-    mSwitchTabs = cg.readEntry( "switchTabs", false );
     mTabView = cg.readEntry( "tabView", ShowText | ShowIcon );
     mSavingDir = cg.readEntry( "savingDir", QString() );
+
+    globalComicUpdater->load();
 }
 
 void ComicApplet::saveConfig()
@@ -668,18 +736,17 @@ void ComicApplet::saveConfig()
     cg.writeEntry( "showErrorPicture", mShowErrorPicture );
     cg.writeEntry( "arrowsOnHover", mArrowsOnHover );
     cg.writeEntry( "middleClick", mMiddleClick );
-    cg.writeEntry( "switchTabTime", mSwitchTabTime );
-    cg.writeEntry( "showTabBar", mShowTabBar );
     cg.writeEntry( "tabIdentifier", mTabIdentifier );
-    cg.writeEntry( "useTabs", mUseTabs );
-    cg.writeEntry( "switchTabs", mSwitchTabs );
     cg.writeEntry( "tabView", mTabView );
     cg.writeEntry( "savingDir", mSavingDir );
+    cg.writeEntry( "checkNewComicStripsIntervall", mCheckNewComicStripsIntervall );
+
+    globalComicUpdater->save();
 }
 
 void ComicApplet::slotChosenDay( const QDate &date )
 {
-    if ( mSuffixType == "Date" ) {
+    if ( mComicType == Date ) {
         if ( date <= mCurrentDay ) {
             QDate temp = QDate::fromString( mFirstIdentifierSuffix, "yyyy-MM-dd" );
             if ( temp.isValid() && date >= temp ) {
@@ -712,6 +779,18 @@ void ComicApplet::slotCurrentDay()
     updateComic( QString() );
 }
 
+void ComicApplet::slotFoundLastStrip( int index, const QString &identifier, const QString &suffix )
+{
+    KConfigGroup cg = config();
+    if ( suffix != cg.readEntry( "lastStrip_" + identifier, QString() ) ) {
+        kDebug() << identifier << "has a newer strip.";
+        mTabBar->setTabHighlighted( index, true );
+        cg.writeEntry( "lastStripVisited_" + identifier, false );
+    }
+
+    mActionNextNewStripTab->setEnabled( mTabBar->hasHighlightedTabs() );
+}
+
 void ComicApplet::slotReload()
 {
     int index = mTabBar->currentIndex();
@@ -724,37 +803,38 @@ void ComicApplet::slotReload()
     }
 }
 
-void ComicApplet::slotStartTimer()
-{
-    if ( mUseTabs && mSwitchTabTime && mSwitchTabs && mTabIdentifier.count() > 1 ) {
-        mReloadTimer->start( mSwitchTabTime * 1000 );
-    } else {
-        mReloadTimer->stop();
-    }
-}
-
 void ComicApplet::slotGoJump()
 {
-    if ( mSuffixType == "Number" ) {
+    if ( mComicType == Number ) {
         QPointer<ChooseStripNumDialog> pageDialog = new ChooseStripNumDialog( 0, mCurrentIdentifierSuffix.toInt(), mFirstStripNum[ mComicIdentifier ], mMaxStripNum[ mComicIdentifier ] );
         if ( pageDialog->exec() == QDialog::Accepted ) {
             updateComic( QString::number( pageDialog->getStripNumber() ) );
         }
         delete pageDialog;
-        slotStartTimer();
-    } else if ( mSuffixType == "Date" ) {
+    } else if ( mComicType == Date ) {
         KDatePicker *calendar = new KDatePicker;
         calendar->setAttribute( Qt::WA_DeleteOnClose );//to have destroyed emitted upon closing
         calendar->setMinimumSize( calendar->sizeHint() );
         calendar->setDate( QDate::fromString( mCurrentIdentifierSuffix, "yyyy-MM-dd" ) );
 
-        connect( calendar, SIGNAL( destroyed( QObject* ) ), this, SLOT( slotStartTimer() ) );
         connect( calendar, SIGNAL( dateSelected( QDate ) ), this, SLOT( slotChosenDay( QDate ) ) );
         connect( calendar, SIGNAL( dateEntered( QDate ) ), this, SLOT( slotChosenDay( QDate ) ) );
         calendar->show();
+    } else if ( mComicType == String ) {
+        bool ok;
+        const QString suffix = KInputDialog::getText( i18n( "Go to Strip" ), i18n( "Strip identifier:" ), mCurrentIdentifierSuffix, &ok );
+        if ( ok ) {
+            updateComic( suffix );
+        }
     }
 }
 
+void ComicApplet::slotNextNewStrip()
+{
+    const int index = mTabBar->currentIndex();
+    mTabBar->setCurrentIndex( mTabBar->nextHighlightedTab( index ) );
+}
+
 void ComicApplet::slotStorePosition()
 {
     KConfigGroup cg = config();
@@ -825,6 +905,40 @@ void ComicApplet::updateSize()
     mImageWidget->update();
 }
 
+void ComicApplet::createComicBook()
+{
+    ComicArchiveDialog *dialog = new ComicArchiveDialog( mComicIdentifier, mComicTitle, mComicType, mCurrentIdentifierSuffix, mFirstIdentifierSuffix, getSavingDir() );
+    dialog->setAttribute( Qt::WA_DeleteOnClose );//to have destroyed emitted upon closing
+    connect( dialog, SIGNAL(archive(int,KUrl,QString,QString)), this, SLOT(slotArchive(int,KUrl,QString,QString)) );
+    dialog->show();
+}
+
+void ComicApplet::slotArchive( int archiveType, const KUrl &dest, const QString &fromIdentifier, const QString &toIdentifier )
+{
+    mSavingDir = dest.directory();
+    saveConfig();
+
+    kDebug() << "Archiving:" << mComicIdentifier <<  archiveType << dest << fromIdentifier << toIdentifier;
+    ComicArchiveJob *job = new ComicArchiveJob( dest, mEngine, static_cast< ComicArchiveJob::ArchiveType >( archiveType ), mComicType,  mComicIdentifier, this );
+    job->setFromIdentifier( mComicIdentifier + ':' + fromIdentifier );
+    job->setToIdentifier( mComicIdentifier + ':' + toIdentifier );
+    if ( job->isValid() ) {
+        connect( job, SIGNAL(finished(KJob*)), this, SLOT(slotArchiveFinished(KJob*)) );
+        KIO::getJobTracker()->registerJob( job );
+        job->start();
+    } else {
+        kWarning() << "Archiving job is not valid.";
+        delete job;
+    }
+}
+
+void ComicApplet::slotArchiveFinished (KJob *job )
+{
+    if ( job->error() ) {
+        KNotification::event( KNotification::Warning, i18n( "Archiving comic failed" ), job->errorText(), KIcon( "dialog-warning" ).pixmap( KIconLoader::SizeMedium ) );
+    }
+}
+
 QList<QAction*> ComicApplet::contextualActions()
 {
     return mActions;
@@ -846,11 +960,7 @@ QSizeF ComicApplet::sizeHint(Qt::SizeHint which, const QSizeF &constraint) const
 
 void ComicApplet::updateComic( const QString &identifierSuffix )
 {
-    //always stop the timer when changing the comic, as not all clicks are caught by mousePressEvent here
-    mReloadTimer->stop();
-
     mEngine = dataEngine( "comic" );
-
     setConfigurationRequired( mComicIdentifier.isEmpty() );
     if ( !mComicIdentifier.isEmpty() && mEngine && mEngine->isValid() ) {
 
@@ -867,7 +977,6 @@ void ComicApplet::updateComic( const QString &identifierSuffix )
             mEngine->disconnectSource( mOldSource, this );
         }
         mOldSource = identifier;
-
         mEngine->disconnectSource( identifier, this );
         mEngine->connectSource( identifier, this );
         const Plasma::DataEngine::Data data = mEngine->query( identifier );
@@ -878,7 +987,6 @@ void ComicApplet::updateComic( const QString &identifierSuffix )
     } else {
         kError() << "Either no identifier was specified or the engine could not be created:" << "id" << mComicIdentifier << "engine valid:" << ( mEngine && mEngine->isValid() );
         setConfigurationRequired( true );
-        slotStartTimer();
     }
 }
 
@@ -904,23 +1012,10 @@ void ComicApplet::updateContextMenu()
     if (mActionShop) {
         mActionShop->setEnabled( mShopUrl.isValid() );
     }
-    mActionGoJump->setEnabled( mSuffixType != "String" );
 }
 
-void ComicApplet::slotSaveComicAs()
+QString ComicApplet::getSavingDir() const
 {
-    KTemporaryFile tempFile;
-
-    if ( !tempFile.open() ) {
-        slotStartTimer();
-        return;
-    }
-
-    // save image to temporary file
-    mImage.save( tempFile.fileName(), "PNG" );
-
-    KUrl srcUrl( tempFile.fileName() );
-
     QString dir = mSavingDir;
     if ( dir.isEmpty() ) {
         dir = KGlobalSettings::picturesPath();
@@ -932,14 +1027,29 @@ void ComicApplet::slotSaveComicAs()
         dir = QDir::homePath();
     }
 
-    QString name = mComicTitle + " - " + mCurrentIdentifierSuffix + ".png";
+    return dir;
+}
 
-    KUrl destUrl = KUrl(dir);
+void ComicApplet::slotSaveComicAs()
+{
+    KTemporaryFile tempFile;
+
+    if ( !tempFile.open() ) {
+        return;
+    }
+
+    // save image to temporary file
+    mImage.save( tempFile.fileName(), "PNG" );
+
+    KUrl srcUrl( tempFile.fileName() );
+
+    QString dir = getSavingDir();
+    const QString name = mComicTitle + " - " + mCurrentIdentifierSuffix + ".png";
+    KUrl destUrl = KUrl( dir );
     destUrl.addPath( name );
 
     destUrl = KFileDialog::getSaveUrl( destUrl, "*.png" );
     if ( !destUrl.isValid() ) {
-        slotStartTimer();
         return;
     }
 
@@ -958,7 +1068,7 @@ void ComicApplet::slotSaveComicAs()
         if (!mAdditionalText.isEmpty() ) {
             res.setProperty(NIE::description(), mAdditionalText);
         }
-        if ((mSuffixType == "Date") && !mShownIdentifierSuffix.isEmpty()) {
+        if ( ( mComicType == Date ) && !mShownIdentifierSuffix.isEmpty() ) {
             res.setProperty(NIE::contentCreated(), QDateTime::fromString(mShownIdentifierSuffix, Qt::ISODate));
         }
         if (!mComicTitle.isEmpty()) {
@@ -993,14 +1103,12 @@ void ComicApplet::slotSaveComicAs()
 #else
     KIO::NetAccess::file_copy( srcUrl, destUrl );
 #endif
-
-    slotStartTimer();
 }
 
 bool ComicApplet::eventFilter( QObject *receiver, QEvent *event )
 {
-    if ( dynamic_cast<QGraphicsWidget *>(receiver) != mMainWidget ) {
-        return false;
+    if ( receiver != mMainWidget ) {
+        return Plasma::PopupApplet::eventFilter( receiver, event );
     }
 
     switch (event->type()) {
@@ -1017,55 +1125,30 @@ bool ComicApplet::eventFilter( QObject *receiver, QEvent *event )
                 mFrameAnim->start();
             }
 
-            break;
-        case QEvent::GraphicsSceneWheel:
-            {
-                slotStartTimer();
-                QGraphicsSceneWheelEvent *e = static_cast<QGraphicsSceneWheelEvent *>( event );
-                if ( mImageWidget->isUnderMouse() && ( e->modifiers() == Qt::ControlModifier ) ) {
-                    const QPointF eventPos = e->pos();
-                    const int numDegrees = e->delta() / 8;
-                    const int numSteps = numDegrees / 15;
-
-                    int index = mTabBar->currentIndex();
-                    int count = mTabBar->count();
-                    int newIndex = 0;
-
-                    if ( numSteps % count != 0 ) {
-                        if ( numSteps < 0 ) {
-                            newIndex = ( index - numSteps ) % count;
-                        } else if ( numSteps > 0 ) {
-                            newIndex = index - ( numSteps % count );
-                            newIndex = newIndex < 0 ? newIndex + count : newIndex;
-                        }
-                        mTabBar->setCurrentIndex( newIndex );
-                    }
-                    e->accept();
-                }
-            }
             break;
         case QEvent::GraphicsSceneMousePress:
             {
-                slotStartTimer();
                 QGraphicsSceneMouseEvent *e = static_cast<QGraphicsSceneMouseEvent *>( event );
                 if ( e->button() == Qt::LeftButton ) {
                     if ( mLabelUrl->isUnderMouse() ) {
                         if ( hasAuthorization( "LaunchApp" ) ) {
                             // link clicked
                             KRun::runUrl( mWebsiteUrl, "text/html", 0 );
+                            return true;
                         }
                     } else if ( mLabelId->isUnderMouse() ) {
                         // identifierSuffix clicked clicked
                         slotGoJump();
+                        return true;
                     } else if ( mImageWidget->isUnderMouse() && ( mMainWidget->geometry().size() != mLastSize ) ) {
                         // only update the size by clicking on the image-rect if the user manual resized the applet
                         updateSize();
+                        return true;
                     }
                 } else if ( ( e->button() == Qt::MidButton ) && mMiddleClick ) { // handle full view
                     fullView();
+                    return true;
                 }
-
-                e->ignore();
             }
             break;
         case QEvent::GraphicsSceneResize:
