@@ -22,6 +22,8 @@
 #ifndef COMIC_H
 #define COMIC_H
 
+#include "comicinfo.h"
+
 #include <QtCore/QDate>
 #include <QtGui/QImage>
 
@@ -32,10 +34,13 @@
 #include <Plasma/TabBar>
 
 class ArrowWidget;
+class CheckNewStrips;
 class ComicModel;
 class ConfigWidget;
 class FullViewWidget;
 class ImageWidget;
+class KAction;
+class KJob;
 class QAction;
 class QGraphicsLayout;
 class QPropertyAnimation;
@@ -61,6 +66,33 @@ class ComicTabBar : public Plasma::TabBar
             }
         }
 
+        bool hasHighlightedTabs() const
+        {
+            for ( int i = 0; i < count(); ++i ) {
+                if ( isTabHighlighted( i ) ) {
+                    return true;
+                }
+            }
+
+            return false;
+        }
+
+        int nextHighlightedTab( int index ) const
+        {
+            int firstHighlighted = -1;
+            for ( int i = 0; i < count(); ++i ) {
+                if ( isTabHighlighted( i ) ) {
+                    if ( i > index ) {
+                        return i;
+                    } else if ( firstHighlighted == -1 ) {
+                        firstHighlighted = i;
+                    }
+                }
+            }
+
+            return ( firstHighlighted != -1 ? firstHighlighted : index );
+        }
+
     protected:
         QSizeF sizeHint( Qt::SizeHint which, const QSizeF &constraint = QSizeF() ) const
         {
@@ -136,9 +168,10 @@ class ComicApplet : public Plasma::PopupApplet
         void slotPreviousDay();
         void slotFirstDay();
         void slotCurrentDay();
+        void slotFoundLastStrip( int index, const QString &identifier, const QString &suffix );
         void slotGoJump();
+        void slotNextNewStrip();
         void slotReload();
-        void slotStartTimer();
         void slotSaveComicAs();
         void slotScaleToContent();
         void slotShop();
@@ -150,10 +183,13 @@ class ComicApplet : public Plasma::PopupApplet
         void buttonBar();
         void fullView();
         void updateSize();
+        void createComicBook();
+        void slotArchive( int archiveType, const KUrl &dest, const QString &fromIdentifier, const QString &toIdentifier );
+        void slotArchiveFinished( KJob *job );
 
     public slots:
         void configChanged();
-        
+
     protected:
         QSizeF sizeHint(Qt::SizeHint which, const QSizeF &constraint = QSizeF()) const;
         bool eventFilter( QObject *receiver, QEvent *event );
@@ -164,11 +200,14 @@ class ComicApplet : public Plasma::PopupApplet
         void updateUsedComics();
         void updateButtons();
         void updateContextMenu();
+        void updateView();
         void saveConfig();
         bool isInPanel() const;
         void setTabBarVisible( bool isVisible );//HACK what was in 4.4 does not seem to work anymore, so this was added
+        QString getSavingDir() const;
 
     private:
+        static const int CACHE_LIMIT;
         ComicModel *mModel;
         QSortFilterProxyModel *mProxy;
 
@@ -181,11 +220,12 @@ class ComicApplet : public Plasma::PopupApplet
         QString mNextIdentifierSuffix;
         QString mPreviousIdentifierSuffix;
         QString mFirstIdentifierSuffix;
+        QString mLastIdentifierSuffix;
         QString mComicAuthor;
         QString mComicTitle;
         QString mStripTitle;
         QString mAdditionalText;
-        QString mSuffixType;
+        IdentifierType mComicType;
         QString mShownIdentifierSuffix;
         QString mCurrentIdentifierSuffix;
         QString mStoredIdentifierSuffix;
@@ -204,8 +244,9 @@ class ComicApplet : public Plasma::PopupApplet
         bool mShowErrorPicture;
         bool mArrowsOnHover;
         bool mMiddleClick;
+        int mCheckNewComicStripsIntervall;
+        CheckNewStrips *mCheckNewStrips;
         QTimer *mDateChangedTimer;
-        QTimer *mReloadTimer;
         QList<QAction*> mActions;
         QGraphicsWidget *mMainWidget;
         QGraphicsLinearLayout *mCentralLayout;
@@ -217,6 +258,7 @@ class ComicApplet : public Plasma::PopupApplet
         QAction *mActionScaleContent;
         QAction *mActionShop;
         QAction *mActionStorePosition;
+        KAction *mActionNextNewStripTab;
         QMap< QString, int > mFirstStripNum;
         QMap< QString, int > mMaxStripNum;
         QSizeF mMaxSize;
@@ -237,11 +279,7 @@ class ComicApplet : public Plasma::PopupApplet
         ArrowWidget *mRightArrow;
 
         //Tabs
-        bool mUseTabs;
-        bool mShowTabBar;
         bool mTabAdded;
-        bool mSwitchTabs;
-        int mSwitchTabTime;
         ComicTabBar *mTabBar;
         QStringList mTabIdentifier;
 
