@@ -220,9 +220,17 @@ void FileWatcher::createConfigurationInterface(KConfigDialog *parent)
     filtersUi.setupUi(widget);
     parent->addPage(widget, i18n("Filters"), icon());
 
-    filtersUi.filtersListBox->setItems(m_filters);
+    filtersUi.filtersListWidget->setItems(m_filters);
     filtersUi.showOnlyMatchesCheckBox->setChecked(m_showOnlyMatches);
     filtersUi.useRegularExpressionsRadioButton->setChecked(m_useRegularExpressions);
+    
+    connect(ui.fontColorButton,SIGNAL(changed (QColor)),parent, SLOT(settingsModified()));
+    connect(ui.fontRequester,SIGNAL(fontSelected (QFont)),parent, SLOT(settingsModified()));
+    connect(ui.pathUrlRequester,SIGNAL(textChanged (QString)),parent, SLOT(settingsModified()));
+    connect(filtersUi.filtersListWidget,SIGNAL(changed ()),parent, SLOT(settingsModified()));
+    connect(filtersUi.showOnlyMatchesCheckBox,SIGNAL(toggled (bool)),parent, SLOT(settingsModified()));
+    connect(filtersUi.useExactMatchRadioButton,SIGNAL(toggled (bool)),parent, SLOT(settingsModified()));
+    connect(filtersUi.useRegularExpressionsRadioButton,SIGNAL(toggled (bool)),parent, SLOT(settingsModified()));
 
 }
 
@@ -244,7 +252,7 @@ void FileWatcher::configAccepted()
     textItem->setDefaultTextColor(ui.fontColorButton->color());
     cg.writeEntry("textColor", ui.fontColorButton->color());
 
-    m_filters = filtersUi.filtersListBox->items();
+    m_filters = filtersUi.filtersListWidget->items();
     cg.writeEntry("filters", m_filters);
 
     m_showOnlyMatches = filtersUi.showOnlyMatchesCheckBox->isChecked();
