@@ -21,6 +21,7 @@
 #define FILEWATCHER_H
 
 #include <Plasma/Applet>
+#include <Plasma/ToolTipManager>
 
 #include "ui_fileWatcherConfig.h"
 #include "ui_filtersConfig.h"
@@ -45,6 +46,10 @@ class FileWatcher : public Plasma::Applet
     void constraintsEvent(Plasma::Constraints constraints);
     QSizeF sizeHint(Qt::SizeHint which, const QSizeF &constraint) const;
 
+    
+  public slots:
+    void configChanged();
+        
   protected slots:
     void configAccepted();
 
