@@ -31,6 +31,8 @@
 #include <QFileInfo>
 #include <QStandardItemModel>
 #include <QThreadPool>
+#include <Plasma/Containment>
+#include <Plasma/Wallpaper>
 
 #include <KDebug>
 #include <KConfigDialog>
@@ -112,7 +114,6 @@ void Frame::init()
     m_waitForResize.setInterval(200);
     
     configChanged();
-    initSlideShow();
     
     KConfigGroup cg = config();
     if (frameReceivedUrlArgs) {
@@ -124,7 +125,51 @@ void Frame::init()
 
     QAction *openAction = action("run associated application");
     openAction->setIcon(SmallIcon("image-x-generic"));
-    openAction->setText(i18n("&Open Picture..."));    
+    openAction->setText(i18n("&Open Picture..."));
+    QAction *wallpaperAction = new QAction(KIcon("user-desktop"),i18n("Set as Wallpaper Image"), this);
+    actions.append(wallpaperAction);
+    connect(wallpaperAction, SIGNAL(triggered(bool)), this, SLOT(setImageAsWallpaper()));
+}
+
+QList<QAction*> Frame::contextualActions()
+{
+    return actions;
+}
+
+void Frame::setImageAsWallpaper()
+{
+  //setting current image of Picture frame as wallaper image
+    KUrl url;
+
+    if (m_slideShow) {
+        url = m_mySlideShow->currentUrl();
+    } else {
+        url = m_currentUrl;
+    }
+
+    kDebug() << KMimeType::findByUrl(url).data()->name();
+
+    if (containment()->wallpaper() && containment()->wallpaper()->supportsMimetype(KMimeType::findByUrl(url).data()->name())) {
+       containment()->wallpaper()->setUrls(url);
+    } else {
+      KPluginInfo::List wallpaperList = containment()->wallpaper()->listWallpaperInfoForMimetype(KMimeType::findByUrl(url).data()->name());
+      KPluginInfo wallpaper;
+      bool image = false;
+      foreach(wallpaper,wallpaperList) {
+        if (wallpaper.pluginName() == "image") {
+           image = true;
+           break;
+         }
+      }
+      if (image) {
+        containment()->setWallpaper("image");
+      } else {
+        containment()->setWallpaper(wallpaperList.at(0).name());
+      }
+      if (containment()->wallpaper()) {
+        containment()->wallpaper()->setUrls(url);
+      }
+    }
 }
 
 void Frame::configChanged()
@@ -145,6 +190,8 @@ void Frame::configChanged()
     m_potdProvider = cg.readEntry("potdProvider", QString());
     m_potd = cg.readEntry("potd", false);
     m_autoUpdateIntervall = cg.readEntry("autoupdate time", 0);
+
+    initSlideShow();
 }
 
 void Frame::slotOpenPicture()
@@ -521,7 +568,7 @@ void Frame::createConfigurationInterface(KConfigDialog *parent)
     connect(m_configDialog->imageUi.removeDirButton, SIGNAL(clicked()), this, SLOT(removeDir()));
     connect(m_configDialog->imageUi.addDirButton, SIGNAL(clicked()), this, SLOT(addDir()));
     connect(m_configDialog->imageUi.slideShowDirList, SIGNAL(currentRowChanged(int)), this, SLOT(updateButtons()));
-
+ 
     m_configDialog->setRoundCorners(m_roundCorners);
     m_configDialog->setShadow(m_shadow);
     m_configDialog->setShowFrame(m_frame);
@@ -550,6 +597,29 @@ void Frame::createConfigurationInterface(KConfigDialog *parent)
     m_configDialog->imageUi.slideShowDelay->setTime(QTime(m_slideshowTime / 3600, (m_slideshowTime / 60) % 60, m_slideshowTime % 60));
     m_configDialog->previewPicture(m_mySlideShow->image());
     m_configDialog->imageUi.autoUpdateTime->setTime(QTime(m_autoUpdateIntervall / 3600, (m_autoUpdateIntervall / 60) % 60));
+    
+    connect(m_configDialog->imageUi.slideShowDelay, SIGNAL(timeChanged(QTime)), 
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->imageUi.pictureComboBox, SIGNAL(currentIndexChanged ( int)), 
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->imageUi.autoUpdateTime, SIGNAL(timeChanged(QTime)), 
+                    parent, SLOT(settingsModified()));
+    connect(m_configDialog->imageUi.addDirButton, SIGNAL(clicked(bool)), 
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->imageUi.removeDirButton, SIGNAL(clicked(bool)), 
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->imageUi.randomCheckBox, SIGNAL(toggled(bool)),
+                   parent, SLOT(settingsModified()));  
+    connect(m_configDialog->imageUi.recursiveCheckBox, SIGNAL(toggled(bool)),
+                   parent, SLOT(settingsModified()));  
+    connect(m_configDialog->appearanceUi.roundCheckBox, SIGNAL(toggled(bool)),
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->appearanceUi.shadowCheckBox, SIGNAL(toggled(bool)),
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->appearanceUi.frameCheckBox, SIGNAL(toggled(bool)),
+                   parent, SLOT(settingsModified()));
+    connect(m_configDialog->appearanceUi.changeFrameColor,SIGNAL(changed (QColor)),
+                    parent, SLOT(settingsModified()));
 }
 
 void Frame::configAccepted()
@@ -674,7 +744,7 @@ void Frame::dropEvent(QGraphicsSceneDragDropEvent *event)
     KUrl droppedUrl = (KUrl::List::fromMimeData(event->mimeData())).at(0);
     kDebug() << "dropped URL" << droppedUrl.url();
     if (droppedUrl.protocol() == "desktop") {
-        KUrl tmpUrl = KGlobalSettings::desktopPath() + droppedUrl.path();
+        KUrl tmpUrl = QString(KGlobalSettings::desktopPath() + droppedUrl.path());
         droppedUrl = tmpUrl;
     }
     // If the url is a local directory start slideshowmode
