@@ -20,6 +20,7 @@
 #define COMIC_DATAENGINE_H
 
 #include "plasma/dataengine.h"
+#include <solid/networking.h>
 
 class ComicProvider;
 
@@ -55,12 +56,15 @@ class ComicEngine : public Plasma::DataEngine
     private Q_SLOTS:
         void finished( ComicProvider* );
         void error( ComicProvider* );
+        void networkStatusChanged( Solid::Networking::Status );
 
     private:
         bool mEmptySuffix;
         void setComicData( ComicProvider *provider );
         QString lastCachedIdentifier( const QString &identifier ) const;
+        QString mIdentifierError;
         QMap<QString, KService::Ptr> mFactories;
+        QHash<QString, ComicProvider*> m_jobs;
 };
 
 K_EXPORT_PLASMA_DATAENGINE( comic, ComicEngine )
